        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
}
