        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 22 <br>1,2,3,8,10,11,14,15,16,17,18,22,23,25,27,31,38,40,42,48,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 19 <strong>control</strong><br>0,4,5,7,9,12,13,21,26,30,32,33,34,36,37,39,43,45,46';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260723 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>6,19,20,24,28,29,35,41,44,47';}
}
